SystemOrganization addCategory: #'ICU-Tests-Core'!

TestCase subclass: #ICUCalendarTest
	instanceVariableNames: 'calendar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICUCalendarTest methodsFor: 'running' stamp: 'JanVanDeSandt 3/2/2012 14:46'!
tearDown

	calendar notNil
		ifTrue: [ calendar close ]! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:53'!
testDutchCalendar

	calendar := ICUCalendar newWithLocale: 'nl' timeZone: 'Europe/Amsterdam'.

	self assert: calendar zoneOffset > 0.
	self assert: calendar dstOffset notNil! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:47'!
testGetAllTimeZones

	| timeZones |
	
	timeZones := ICUCalendar allTimeZones.
	
	self assert: (timeZones includes: 'Europe/Amsterdam')! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:51'!
testGetDayOfYear

	calendar := ICUCalendar new.

	self assert: calendar dayOfYear < 370! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:52'!
testGetDefaultTimeZone

	| timeZone |
	
	timeZone := ICUCalendar defaultTimeZone.
	
	self assert: timeZone isString! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 14:51'!
testGetOffsets

	calendar := ICUCalendar new.

	self assert: calendar zoneOffset notNil.
	self assert: calendar dstOffset notNil! !

!ICUCalendarTest methodsFor: 'tests' stamp: 'jvds 6/13/2011 14:29'!
testStability

	100 timesRepeat: [ self testGetAllTimeZones ] ! !

TestCase subclass: #ICUConverterTest
	instanceVariableNames: 'converter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ICUConverterTest methodsFor: 'utility' stamp: 'jvds 2/26/2012 22:21'!
asString: aCollectionOfIntegers

	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!ICUConverterTest methodsFor: 'utility' stamp: 'jvds 2/26/2012 14:50'!
specialCharsString

	^ self asString: #(83 233 228 115 238 100 233)! !

!ICUConverterTest methodsFor: 'running' stamp: 'jvds 2/26/2012 14:14'!
tearDown

	converter notNil
		ifTrue: [
			converter close.
			converter := nil ]! !

!ICUConverterTest methodsFor: 'tests' stamp: 'jvds 2/26/2012 14:06'!
testAllNames

	| names |
	
	names := ICUConverter allNames.
	
	self assert: (names includes: 'UTF-8')! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 16:31'!
testByteStringAsUTF8

	| output |

	output := ICUConverter byteStringAsUTF8: self specialCharsString.
	self assert: output = #[ 83 195 169 195 164 115 195 174 100 195 169 ]! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 17:12'!
testOpenUTF8Converter

	| text utf16 |

	converter := ICUConverter openUTF8.
	self assert: converter name = 'UTF-8'.
	self assert: converter type = ICUConverter converterTypeUTF8.
	self deny: converter isFixedWidth.
	self deny: converter isAmbiguous.
	
	text := 'Smalltalk'.
	utf16 := converter toUTF16: text.
	
	self assert: utf16 isTwoByteString.
	self assert: utf16 size = text size.
	self assert: (converter fromUTF16: utf16) asString = text! !

!ICUConverterTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 17:12'!
testUTF8ConverterWithSpecialChars

	| text utf16 |

	converter := ICUConverter openISO_8859_1.
	
	text := self specialCharsString.
	utf16 := converter toUTF16: text.
	
	self assert: utf16 isTwoByteString.
	self assert: utf16 size = text size.
	self assert: (converter fromUTF16: utf16) asString = text! !

TestCase subclass: #ITwoByteStringTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ICU-Tests-Core'!

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 2/25/2012 19:54'!
testAsUTF16Bytes

	| string expected |
	
	string := 'Jan' asUTF16String.
	
	expected := Smalltalk isLittleEndian
		ifTrue: [ #[ 74 0 97 0 110 0 ] ]
		ifFalse: [ #[ 0 74 0 97 0 110 ] ].
		
	self assert: expected = string asUTF16Bytes! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 2/21/2012 22:21'!
testAsUTF16String

	| string |
	
	string := 'Jan' asUTF16String.
		
	self assert: string isTwoByteString.
	self assert: string size = 3.
	self assert: string printString = 'Jan' printString.
	
	self assert: string asUTF16String == string! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 3/2/2012 15:04'!
testEquals

	| string |
	
	string := TwoByteString new: 3.
	string
		at: 1 put: $J ;
		at: 2 put: $a ;
		at: 3 put: $n.
		
	self assert: string = 'Jan'.
	self assert: 'Jan' = string.
	self assert: string hash = 'Jan' hash! !

!ITwoByteStringTest methodsFor: 'tests' stamp: 'JanVanDeSandt 2/21/2012 22:07'!
testNewString

	| string |
	
	string := TwoByteString new: 3.
	string
		at: 1 put: $J ;
		at: 2 put: $a ;
		at: 3 put: $n.
		
	self assert: string size = 3.
	self assert: string first = $J.
	self assert: string last = $n.
	self assert: string printString = 'Jan' printString! !
